//  Copyright (C) 2010 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#ifndef HOSTBOX_H
#define HOSTBOX_H
#include <gtkmm.h>
#include <string>
#include "frame-box.h"

class Host;
class HostBox: public FrameBox
{
 public:
     HostBox(Host *host, bool show_name, bool show_numeric_id, double row_height, double column_width,
             Pango::AttrList host_text_attributes);
     void set_host(Host *host);
    ~HostBox();
 private:
    Pango::AttrList text_attributes;
};

#endif
